@@ -42,7 +42,7 @@ from .core import (astroscrappy_lacosmic,
                    identify_technique,
                    image_overscan,
                    image_trim,
-                   interpolate,
+                   interpolate_spectrum,
                    is_file_saturated,
                    linearize_spectrum,
                    name_master_flats,
