@@ -111,7 +111,7 @@ class ImageProcessor(object):
                                 reduced_data=self.args.red_path,
                                 technique=self.technique)
 
-                    elif len(group_obstype) == 1 and group_obstype[0] == 'FLAT':
+                    elif len(group_obstype) == 1 and group_obstype[0] in ['FLAT', 'LAMPFLAT']:
                         log.debug('Create Master FLATS')
                         flat_files = sub_group.file.tolist()
                         sample_header = fits.getheader(os.path.join(
@@ -497,7 +497,8 @@ class ImageProcessor(object):
                             trim_section=self.trim_section,
                             master_bias_name=self.master_bias_name,
                             new_master_flat_name=master_flat_name,
-                            saturation_threshold=self.args.saturation_threshold)
+                            saturation_threshold=self.args.saturation_threshold,
+                            ignore_bias=self.args.ignore_bias)
         else:
             log.error('There is no valid datatype in this group')
 
@@ -586,7 +587,3 @@ class ImageProcessor(object):
                 log.info('Created science file: {:s}'.format(final_name))
         else:
             log.error('Can not process data without a master flat')
-
-
-if __name__ == '__main__':
-    pass
