@@ -2,5 +2,5 @@
 
 """
 from __future__ import absolute_import
-from .redspec import MainApp, get_args
+from .redspec import ReduceSpectroscopy, get_args
 from .wavelength import WavelengthCalibration
