@@ -14,6 +14,17 @@ Simon Torres 2016-06-28
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+import sys
+import os
+import argparse
+import astropy.units as u
+import logging
+from ccdproc import CCDData
+
+import matplotlib.pyplot as plt
+import warnings
+from importlib.metadata import version
+
 from .wavelength import WavelengthCalibration
 from ..core import (classify_spectroscopic_data,
                     search_comp_group,
@@ -28,21 +39,11 @@ from ..core import (NoMatchFound,
                     NoTargetException,
                     ReferenceData)
 
-import sys
-import os
-import argparse
-import astropy.units as u
-import logging
-from ccdproc import CCDData
-
-import matplotlib.pyplot as plt
-import warnings
-
 SHOW_PLOTS = True
 
 warnings.filterwarnings('ignore')
 
-__version__ = __import__('goodman_pipeline').__version__
+__version__ = version('goodman_pipeline')
 
 
 def get_args(arguments=None):
@@ -91,7 +92,7 @@ def get_args(arguments=None):
                         type=str,
                         metavar='<Search Pattern>',
                         dest='pattern',
-                        help="Pattern for matching the goodman's reduced data.")
+                        help="Pattern for matching the goodman's reduced data. Default is cfzst*.")
 
     parser.add_argument('--output-prefix',
                         action='store',
@@ -111,6 +112,15 @@ def get_args(arguments=None):
                              "'optimal'. Only fractional pixel extraction is "
                              "implemented. Default 'fractional'.")
 
+    parser.add_argument('--extraction-width',
+                        action='store',
+                        dest='extraction_width',
+                        type=int,
+                        default=2,
+                        help="Width of the extraction area as a function of target's spatial profile FWHM. For instance "
+                             "if `extraction_with` is set to 1 the extracted area is 0.5 to each side from the center of "
+                             "the traced target. Default 2.")
+
     parser.add_argument('--fit-targets-with',
                         action='store',
                         default='moffat',
@@ -163,6 +173,11 @@ def get_args(arguments=None):
                         help="Maximum number of targets to be found in a "
                              "single image. Default 3")
 
+    parser.add_argument('--disable-background-extraction',
+                        action='store_true',
+                        dest='disable_background_extraction',
+                        help="Disable background extraction")
+
     parser.add_argument('--background-threshold',
                         action='store',
                         dest='background_threshold',
@@ -172,6 +187,25 @@ def get_args(arguments=None):
                              "discriminate usable targets. Default 3 times "
                              "background level")
 
+    parser.add_argument('--background-spacing-factor',
+                        action='store',
+                        dest='background_spacing_factor',
+                        type=float,
+                        default=3,
+                        help="Number of target's  spatial profile standard deviations to separate the target extraction "
+                             "to the background. This is from the edge of the extraction zone to the edge of "
+                             "the background region. Default 3.")
+
+    parser.add_argument('--line-detection-threshold',
+                        action='store',
+                        dest='line_detection_threshold',
+                        type=int,
+                        default=3,
+                        choices=range(0, 101),
+                        metavar='[0-100]',
+                        help="Percent of peak value used to get line detection threshold. "
+                             "The final value is calculated as minimum + 'percent of maximum'. Default value is 3.")
+
     parser.add_argument('--save-plots',
                         action='store_true',
                         dest='save_plots',
@@ -237,16 +271,16 @@ def get_args(arguments=None):
     return args
 
 
-class MainApp(object):
+class ReduceSpectroscopy(object):
     """Defines and initialize all important variables for processing the data
 
-    The MainApp class controls the way the night is organized for further
+    The ReduceSpectroscopy class controls the way the night is organized for further
     processing. It also sets the appropriate parameters that will allow for a
     smooth working in all the other modules.
 
     """
     def __init__(self):
-        """Init method for MainApp class
+        """Init method for ReduceSpectroscopy class
 
         This method initializes the arguments for the class, if they are not
         provided it will get them.
@@ -261,7 +295,7 @@ class MainApp(object):
         self._pipeline_version = __version__
 
     def __call__(self, args=None):
-        """Call method for the MainApp class
+        """Call method for the ReduceSpectroscopy class
 
         This method call the higher level functions in order to do the
         spectroscopic data reduction.
@@ -295,7 +329,7 @@ class MainApp(object):
         else:
             self.log.debug("Received non-empty data container.")
 
-        self.log.debug("Calling _run method for MainApp")
+        self.log.debug("Calling _run method for ReduceSpectroscopy")
         self._run(data_container=data_container,
                   extraction_type=self.args.extraction_type,
                   target_fit_model=self.args.target_fit_model,
@@ -445,7 +479,10 @@ class MainApp(object):
                                 ccd=ccd,
                                 target_trace=single_trace,
                                 spatial_profile=single_profile,
-                                extraction_name=extraction_type)
+                                extraction_name=extraction_type,
+                                extraction_width=self.args.extraction_width,
+                                background_spacing_factor=self.args.background_spacing_factor,
+                                disable_background_extraction=self.args.disable_background_extraction)
 
                             saved_ccd = save_extracted(
                                 ccd=extracted,
@@ -469,7 +506,10 @@ class MainApp(object):
                                         ccd=comp_lamp,
                                         target_trace=single_trace,
                                         spatial_profile=single_profile,
-                                        extraction_name=extraction_type)
+                                        extraction_name=extraction_type,
+                                        extraction_width=self.args.extraction_width,
+                                        background_spacing_factor=self.args.background_spacing_factor,
+                                        disable_background_extraction=self.args.disable_background_extraction)
                                     save_extracted(
                                         ccd=extracted_lamp,
                                         destination=self.args.destination,
@@ -487,7 +527,7 @@ class MainApp(object):
                                 ax.set_ylabel("Intensity (ADU)")
                                 ax.set_xlabel("Dispersion Axis (Pixels)")
 
-                                fig.canvas.set_window_title(
+                                fig.canvas.manager.set_window_title(
                                     'Extracted Data: Target Center ~ '
                                     '{:.2f}'.format(single_profile_center))
 
@@ -546,7 +586,7 @@ class MainApp(object):
 
 
 if __name__ == '__main__':  # pragma: no cover
-    MAIN_APP = MainApp()
+    MAIN_APP = ReduceSpectroscopy()
     try:
         MAIN_APP()
     except KeyboardInterrupt:
